%==========================================================================
%
%   Evaluate numerical approximation to the area of Y with respect to X by
%   applying Simpson's rule.
%
%   INPUTS:
%
%       Y = fevals.
%       X = Dependent variable samples.
%
%==========================================================================
%
%   James Nagel
%   Department of Electrical and Computer Engineering
%   University of Utah, Salt Lake City, Utah
%   nageljr@ieee.org
%   Copyright January 18, 2012

function A = Simpson_rule(X,Y)

%  Calculate spacings.
dx = diff(X);

%  Number of subintervals.
n = length(dx);

%  Assume grid spacings are uniform.
dx = dx(1);

%  Instantiate approximate area.
A = 0;

%  Generate even/odd indices.
i_e = 2:2:n;        %  Even
i_o = 3:2:n;        %  Odd

A = (dx/3)*(Y(1) + 4*sum(Y(i_e)) + 2*sum(Y(i_o)) + Y(end) );



return;


