%==========================================================================
%
%   Evaluate numerical approximation to the area of Y with respect to X by
%   applying the trapezoidal integration rule.
%
%   INPUTS:
%
%       Y = fevals.
%       X = Dependent variable samples.
%
%==========================================================================
%
%   James Nagel
%   Department of Electrical and Computer Engineering
%   University of Utah, Salt Lake City, Utah
%   nageljr@ieee.org
%   Copyright January 18, 2012

function A = trapezoid_rule(X,Y)

%  Calculate spacings.
dx = diff(X);

%  Instantiate approximate area.
A = 0;

%  Begin adding up trapezoidal areas.
for n = 1:length(dx)
    A = A + (dx(n)/2)*(Y(n) + Y(n+1));
end

return;


